#!/usr/bin/env python
# das.py

"""
Author : peters 

Revision History:
File created on 29 Sep 2009.

"""
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~
# qsub (ijet)
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~

#$ -N das.py
#$ -A co2
#$ -cwd
#$ -pe hcomp 2
#$ -r y
#$ -l h_rt=03:00:00
#$ -S /bin/sh
#$ -j y
#$ -v PYTHONPATH
#$ -v NETCDF
#$ -v LD_LIBRARY_PATH

if __name__ == "__main__":
    import sys
    import os
    import logging
    import shutil

# Append current working dir to path

    sys.path.append(os.getcwd())

# Import methods and classes contained in this package

    from da.tools.initexit import CleanUpCycle
    from da.tools.initexit import ValidateOptsArgs
    from da.tools.initexit import ParseOptions
    from da.tools.initexit import StartLogger
    from da.tools.pipeline import *

# Start a logger for all that happens from here on

    dummy   = StartLogger()

# Parse options from the command line

    opts, args = ParseOptions()

# Validate Options and arguments passed

    opts,args   = ValidateOptsArgs(opts,args)

# Start the subprocesses

    msg         = header+"starting JobStart"+footer           ; logging.info(msg) 
    DaCycle   = JobStart(opts,args)

    msg         = header+"starting JobInput"+footer           ; logging.info(msg) 
    StateVector = JobInput(DaCycle)

    msg         = header+"starting SampleState"+footer         ; logging.info(msg) 
    dummy       = SampleState(DaCycle,StateVector)

    msg         = header+"starting Invert"+footer             ; logging.info(msg) 
    dummy       = Invert(DaCycle, StateVector)

    msg         = header+"starting Advance"+footer          ; logging.info(msg) 
    dummy       = Advance(DaCycle, StateVector)

    msg         = header+"starting SaveAndSubmit"+footer      ; logging.info(msg) 
    dummy       = SaveAndSubmit(DaCycle, StateVector)

    msg         = "Cycle finished...exiting"     ; logging.info(msg)

    dummy       = CleanUpCycle(DaCycle)

    sys.exit(0)
